@@ -1,6 +1,9 @@
 /*PGR-GNU*****************************************************************
 File:  pgr_allpairs.hpp
 
+Copyright (c) 2015 pgRouting developers
+Mail: project@pgrouting.org
+
 Copyright (c) 2015 Celia Virginia Vergara Castillo
 Mail: vicky_vergara@hotmail.com
 
@@ -47,6 +50,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 // TODO(vicky) don't keep it here
 #include "cpp_common/pgr_alloc.hpp"
 
+namespace pgrouting  {
 template < class G > class Pgr_allpairs;
 
 // user's functions
@@ -257,5 +261,6 @@ class Pgr_allpairs {
      };
 };
 
+}  // namespace pgrouting
 
 #endif  // INCLUDE_ALLPAIRS_PGR_ALLPAIRS_HPP_
