@@ -1,6 +1,9 @@
 /*PGR-GNU*****************************************************************
 File: pgr_palloc.cpp
 
+Copyright (c) 2015 pgRouting developers
+Mail: project@pgrouting.org
+
 Copyright (c) 2015 Celia Virginia Vergara Castillo
 Mail: vicky_vergara@hotmail.com
 
@@ -26,6 +29,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <cstring>
 #include <string>
 
+namespace pgrouting {
+
 char *
 pgr_msg(const std::string &msg) {
     char* duplicate = NULL;
@@ -35,3 +40,4 @@ pgr_msg(const std::string &msg) {
     return duplicate;
 }
 
+}  // namespace pgrouting
